@@ -74,7 +74,7 @@ class GatewayServer(threading.Thread):
     body = {}
     if len(await request.body()) > 0:
       body = await request.json()
-    input = {**request.path_params, **body}
+    input = {**request.path_params, **request.query_params, **body}
     handler = self.handlers[path]
     try:
       raw_output = self.client.request(handler['service'], handler['method'], input, raw_output=True)
